<!-- warning: Please don't edit this file. It was automatically generated. -->

# winui2-Microsoft.UI.Xaml.XamlTypeInfo

Windows Runtime (WinRT) APIs for for the `winui2-Microsoft.UI.Xaml.XamlTypeInfo` namespace.

This package provides the `winui2.microsoft.ui.xaml.xamltypeinfo` module.
